A cache that holds a limited number of key-value pairs. When the capacity of the cache is exceeded, the least-recently-used (where “used” means a look-up or putting the pair into the cache) pair is automatically removed.
Examples
let mut cache = LruCache::new(2);
cache.insert(1, 10);
cache.insert(2, 20);
cache.insert(3, 30);
assert!(cache.get_mut(&1).is_none());
assert_eq!(*cache.get_mut(&2).unwrap(), 20);
assert_eq!(*cache.get_mut(&3).unwrap(), 30);
cache.insert(2, 22);
assert_eq!(*cache.get_mut(&2).unwrap(), 22);
cache.insert(6, 60);
assert!(cache.get_mut(&3).is_none());
cache.set_capacity(1);
assert!(cache.get_mut(&2).is_none());The cache can also be limited by an arbitrary metric calculated from its key-value pairs, see