Module meter
lru_
cache_
map
0.2.0
Module meter
Module Items
Structs
Traits
In crate lru_
cache_
map
lru_cache_map
Module
meter
Define the Meter trait to track cache resource usage.
Structs

Count
A Meter that measures cache size by counting object number.
Traits

Meter
A trait for measuring the size of a cache item.